@@ -59,6 +59,13 @@ from .technicalslocal.charts import Renko, PnF, LineBreak
 # iq option api
 
 from .iqoptions.iq import iq_login, iq_buy_binary, iq_sell_binary, \
-    iq_get_candles, iq_get_all_candles, iq_get_data_needed, iq_fast_data, iq_get_balance, iq_market_isOpen, iq_get_payout
+    iq_get_candles, iq_get_all_candles, iq_get_data, iq_fast_data, iq_get_balance, iq_market_isOpen, iq_get_payout
+
+
+
+
+# candlestick pattern
+
+from .technicalslocal.candlestick import candlestick
 
     
\ No newline at end of file
