@@ -946,7 +946,7 @@ class indicators:
          The bands automatically widen when volatility increases and narrow when volatility decreases.
 
          This method allows input of some other form of moving average like EMA or KAMA around which BBAND will be formed.
-         Pass desired moving average as <MA> argument. For example BBANDS(MA=TA.KAMA(20)).
+         Pass desired moving average as <MA> argument. For example BBANDS(MA=indicators.KAMA(20)).
          """
 
         std = ohlc[column].rolling(window=period).std()
@@ -1001,7 +1001,7 @@ class indicators:
         %b equals 1 at the upper band and 0 at the lower band.
         """
 
-        BB = TA.BBANDS(ohlc, period, MA, column)
+        BB = indicators.BBANDS(ohlc, period, MA, column)
         percent_b = pd.Series(
             (ohlc["close"] - BB["BB_LOWER"]) / (BB["BB_UPPER"] - BB["BB_LOWER"]),
             name="%b",
@@ -2001,7 +2001,7 @@ class indicators:
         """
 
         hl2 = (ohlc["high"] + ohlc["low"]) / 2
-        tp = TA.TP(ohlc)
+        tp = indicators.TP(ohlc)
         smav = ohlc["volume"].rolling(window=period).mean()
         mf = pd.Series((ohlc["close"] - hl2 + tp.diff()), name="mf")
 
@@ -2044,7 +2044,7 @@ class indicators:
         :smoothing_factor: Specifies the number of periods used in the short moving average
         """
 
-        typical = TA.TP(ohlc)
+        typical = indicators.TP(ohlc)
         # historical interday volatility and cutoff
         inter = typical.apply(np.log).diff()
         # stdev of linear1
@@ -2201,7 +2201,7 @@ class indicators:
 
 
     @classmethod
-    def WILLIAMS_FRACTAL(cls, ohlc: DataFrame, period: int = 2) -> DataFrame:
+    def WILLIAMS_FRACindicatorsL(cls, ohlc: DataFrame, period: int = 2) -> DataFrame:
         """
         Williams Fractal Indicator
         Source: https://www.investopedia.com/terms/f/fractal.asp
@@ -2238,4 +2238,4 @@ class indicators:
 
 
 if __name__ == "__main__":
-    print([k for k in TA.__dict__.keys() if k[0] not in "_"])
\ No newline at end of file
+    print([k for k in indicators.__dict__.keys() if k[0] not in "_"])
\ No newline at end of file
